import 'package:basic_ui/src/providers/theme_provider.dart';
import 'package:flutter/material.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:hooks_riverpod/hooks_riverpod.dart';

import '../models/basic_page_header_data.dart';
import '../widgets/basic_detail.dart';

/// Widget to display some important information on page header
class BasicPageHeader extends HookWidget {
  const BasicPageHeader({
    Key? key,
    required this.pageHeaderData,
    this.color,
  }) : super(key: key);

  /// A list of page header data.
  final List<List<BasicPageHeaderData>> pageHeaderData;

  /// [BasicPageHeader] color.
  final Color? color;

  @override
  Widget build(BuildContext context) {
    final theme = useProvider(themeProvider).theme;

    List<Widget> buildDescriptionBlock() {
      final List<Widget> widgets = [];

      final pageHeaderDataLength = pageHeaderData.length;
      for (int i = 0; i < pageHeaderDataLength; i++) {
        final List<Widget> rowChildren = [];
        for (int x = 0; x < pageHeaderData[i].length; x++) {
          rowChildren.add(Expanded(
            child: BasicDetail(
              title: pageHeaderData[i][x].title,
              subTitle: pageHeaderData[i][x].subTitle,
            ),
          ));

          if (x == 0) {
            rowChildren.add(const SizedBox(width: 8));
          }
        }
        widgets.add(Row(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: rowChildren,
        ));

        widgets.add(const SizedBox(height: 16));
      }

      return widgets;
    }

    return Container(
      color: color ?? theme.primaryColor,
      child: Padding(
        padding: const EdgeInsets.all(16.0),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: buildDescriptionBlock(),
        ),
      ),
    );
  }
}
